aboutsummaryrefslogtreecommitdiffstats
path: root/les
diff options
context:
space:
mode:
Diffstat (limited to 'les')
-rw-r--r--les/handler.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/les/handler.go b/les/handler.go
index 77bc077a2..a8b2486a6 100644
--- a/les/handler.go
+++ b/les/handler.go
@@ -87,8 +87,8 @@ type BlockChain interface {
}
type txPool interface {
- // AddTransactions should add the given transactions to the pool.
- AddBatch([]*types.Transaction) error
+ // AddRemotes should add the given transactions to the pool.
+ AddRemotes([]*types.Transaction) error
}
type ProtocolManager struct {
@@ -803,7 +803,7 @@ func (pm *ProtocolManager) handleMsg(p *peer) error {
return errResp(ErrRequestRejected, "")
}
- if err := pm.txpool.AddBatch(txs); err != nil {
+ if err := pm.txpool.AddRemotes(txs); err != nil {
return errResp(ErrUnexpectedResponse, "msg: %v", err)
}